OtaResponseData class

Constructors

OtaResponseData({required int version, required bool delta, required String localeCode, Map<String, String>? strings, List<String>? removedKeys})
OtaResponseData.fromJson(Map<String, dynamic> json)
factory

Properties

delta bool
final
hashCode int
The hash code for this object.
no setterinherited
localeCode String
final
removedKeys List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings Map<String, String>?
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited